<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php $header_image = get_header_image();
	if ( ! empty( $header_image ) ) { ?>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
		</a>
	<?php } // if ( ! empty( $header_image ) ) ?>

 *
 * @package willingness
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Rework this function to remove WordPress 3.4 support when WordPress 3.6 is released.
 *
 * @uses willingness_header_style()
 * @uses willingness_admin_header_style()
 * @uses willingness_admin_header_image()
 *
 * @package willingness
 */
function willingness_custom_header_setup() {
	$args = array(
		'default-image'          => get_template_directory_uri() . '../images/header.jpg',
		'default-text-color'     => '000',
		'width'                  => 1140,
		'height'                 => 350,
		'flex-height'            => true,
		'wp-head-callback'       => 'willingness_header_style',
		'admin-head-callback'    => 'willingness_admin_header_style',
		'admin-preview-callback' => 'willingness_admin_header_image',
	);


	$args = apply_filters( 'willingness_custom_header_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-header', $args );
	}
}
add_action( 'after_setup_theme', 'willingness_custom_header_setup' );

/**
 * Shiv for get_custom_header().
 *
 * get_custom_header() was introduced to WordPress
 * in version 3.4. To provide backward compatibility
 * with previous versions, we will define our own version
 * of this function.
 *
 * @todo Remove this function when WordPress 3.6 is released.
 * @return stdClass All properties represent attributes of the curent header image.
 *
 * @package willingness
 */

if ( ! function_exists( 'get_custom_header' ) ) {
	function get_custom_header() {
		return (object) array(
			'url'           => get_header_image(),
			'thumbnail_url' => get_header_image(),
			'width'         => HEADER_IMAGE_WIDTH,
			'height'        => HEADER_IMAGE_HEIGHT,
		);
	}
}

if ( ! function_exists( 'willingness_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see willingness_custom_header_setup().
 */
function willingness_header_style() {
	$header_text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == $header_text_color )
		return;

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $header_text_color ) :
	?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo $header_text_color; ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // willingness_header_style

if ( ! function_exists( 'willingness_admin_header_style' ) ) : /**  * Styles
the header image displayed on the Appearance > Header admin panel.  *  * @see
willingness_custom_header_setup().  */ function
willingness_admin_header_style() { ?>     <style type="text/css">
	.appearance_page_custom-header #headimg {
         border: none;
         max-width: 1140px;
}

	#headimg h1,
	#desc {
		margin-left: 50px;
		text-shadow: 2px 2px #e6e6e6;
}

    #headimg h1 {
    	margin-left: 50px !important;
    	font-size: 4em;
		font-family: sans-serif;
		font-weight: normal;
		margin: 0.2em 0 .67em 0;
}

	#headimg h1 a {
		text-decoration: none;
		color: #4ca6cf;

}

	#desc {
		padding: 0px 0px 20px 0px;
		color: #404040;
}

	#headimg img {
}     #     </style> <?php } endif;
// willingness_admin_header_style

if ( ! function_exists( 'willingness_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see willingness_custom_header_setup().
 */
function willingness_admin_header_image() {
	$header_text_color = get_header_textcolor();
?>
	<div id="headimg">
		<?php
		if ( 'blank' == $header_text_color || '' == $header_text_color )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:' . $header_text_color . ';"';
		?>
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php
}
endif; // willingness_admin_header_image
